**Typical Attributes**

.. note::

    This table describes attributes that typically belong to objects of this class.
    Async PRAW dynamically provides the attributes that Reddit returns via the API.
    Since those attributes are subject to change on Reddit's end, Async PRAW makes no
    effort to document any new/removed/changed attributes, other than to instruct you on
    how to discover what is available. As a result, this table of attributes may not be
    complete. See :ref:`determine-available-attributes-of-an-object` for detailed
    information.

    If you would like to add an attribute to this table, feel free to open a `pull
    request <https://github.com/praw-dev/asyncpraw/pulls>`_.
